@@ -3,8 +3,10 @@ import os
 import logging
 import csv
 from .azure_cis_tool import azure_cis as azure_cis_tool
+from . import az_cis_metadata
 from . import utils
 
+
 def get_issues_from_csv_file(config_issues_csv, assetid):
     findings = []
     with open(config_issues_csv, "r") as csv_file:
@@ -13,10 +15,20 @@ def get_issues_from_csv_file(config_issues_csv, assetid):
             if 'Failed' not in row['RESULT']:
                 continue
             issue = { }
-            issue['twc_id'] = 'cis-azure-bench-check-'+row['CHECK'].split()[0]
+            check_id = row['CHECK'].split()[0]
+            issue['twc_id'] = 'cis-azure-bench-check-'+check_id
             issue['asset_id'] = assetid
             issue['twc_title'] = row['CHECK']
-            issue['details'] = row['DETAILS']
+            az_md = az_cis_metadata.az_cis_metadata[check_id]
+            details = "Category: " + az_md['category'] + "\n\n"
+            details = details + "Description: " + az_md['description'] + "\n\n"
+            details = details + "Rationale: " + az_md['rationale'] + "\n\n"
+            if len(row['DETAILS']) > 0:
+                details = details + "Findings:\n" + row['DETAILS'] + "\n\n"
+            if len(az_md['remediation']) > 0:
+                details = details + "Remediation: " + az_md['remediation'] + "\n\n"
+            details = details + "Recommendation: " + az_md['recommendation'] + "\n\n"
+            issue['details'] = details
             issue['type'] = 'Azure CIS'
             issue['rating'] = '4'
             issue['object_id'] = row['SUBSCRIPTION']
