@@ -454,6 +454,7 @@ def discover_host(args, host):
     asset_data['products'] = plist
     asset_tags = []
     asset_tags.append('OS_RELEASE:' + os)
+    asset_tags.append(os)
     if atype != "Mac OS":
         asset_tags.append('Linux')
     asset_tags.append(atype)
@@ -518,9 +519,11 @@ def run_ssh_audit(args, assetid, ip):
                 if '--' in l:
                     rating = l.split('--')[1].split()[0]
                     detail = l.split('--')[1].split(']')[1].strip()
-                else:
+                elif '`-' in l:
                     rating = l.split('`-')[1].split()[0]
                     detail = l.split('`-')[1].split(']')[1].strip()
+                else:
+                    continue
                 if rating == '[fail]':
                     rating = '4'
                 else:
