@@ -476,6 +476,12 @@ def add_attack_surface_label(args, assets):
         elif args.mode == 'nmap':
             if asset['type'] == 'HP Printer':
                 as_label = "Corporate::Printer::HP Printer"
+            elif asset['type'] == 'Arecont Vision':
+                as_label = "Corporate::CCTV::Arecont Vision"
+            elif asset['type'] == 'Axis Communications':
+                as_label = "Corporate::CCTV::Axis Communications"
+            elif asset['type'] == 'Hanwha Vision':
+                as_label = "Corporate::CCTV::Hanwha Vision"
             else:
                 as_label = get_host_as_label("Corporate::Server", asset)
         elif args.mode == 'docker':
@@ -511,7 +517,10 @@ def add_attack_surface_label(args, assets):
         elif args.mode == 'gcloud_functions':
             as_label = get_code_as_label("Cloud::GCP::Serverless", asset)
         elif args.mode == 'meraki' or args.mode == 'dna_center':
-            as_label = get_code_as_label("Corporate::Network::Cisco", asset)
+            if asset['type'] == 'Android':
+                as_label = "Corporate::Mobile Device::Android"
+            else:
+                as_label = get_code_as_label("Corporate::Network::Cisco", asset)
 
         if as_label is not None:
             asset['attack_surface_label'] = as_label
@@ -1077,13 +1086,15 @@ def main(args=None):
         # Arguments required for nmap discovery
         parser_nmap = subparsers.add_parser ("nmap", help = "Discover endpoints and services as assets using nmap")
         parser_nmap.add_argument('--hosts', help='Hostname, IP address or CIDR range. Multiple values should be comma separated')
-        parser_nmap.add_argument('--services', nargs='+', choices=['web', 'database', 'os', 'vmware', 'printers'], help='Specify what class of services / devices you want to scan', default='web')
+        parser_nmap.add_argument('--services', nargs='+', choices=['web', 'database', 'os', 'vmware', 'printers', 'cctv', 'snmp'], help='Specify what class of services / devices you want to scan', default='web')
         parser_nmap.add_argument('--extra_ports', help='List of comma separated ports that you would like to include in the scans in addition to the standard service ports e.g. 444,9000-9100,...')
         parser_nmap.add_argument('--timing', help=argparse.SUPPRESS, default='5')
         parser_nmap.add_argument('--discovery_scan_type', help=argparse.SUPPRESS)
         parser_nmap.add_argument('--discovery_port_list', help=argparse.SUPPRESS)
         parser_nmap.add_argument('--no_ssh_audit', action='store_true', help='Skip ssh audit')
         parser_nmap.add_argument('--include_info', help=argparse.SUPPRESS, action='store_true')
+        parser_nmap.add_argument('--snmp_community', help=argparse.SUPPRESS, default='public')
+        parser_nmap.add_argument('--snmp_security_name', help=argparse.SUPPRESS)
         
         # Arguments required for SBOM-based discovery
         parser_sbom = subparsers.add_parser("sbom", help = "Ingest asset inventory from SBOM (Software Bill Of Materials)")
